from setuptools import find_packages, setup


setup(
    name='physics',
    packages=find_packages(),
    version='0.1.0',
    description='My first Python library',
    author='Nick Chimitt',
    license='MIT',
)